/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AuditConsoleTreeBranchJNDIVO.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.view.tree {
import mx.controls.Alert;
import mx.managers.PopUpManager;

import org.ow2.jonas.admin.auditconsole.util.JaxwsIdentifierParser;

/**
 * Tree branch for Jaxws reports.
 */
public class JaxwsTreeBranch extends AbstractTreeBranch {

    /**
     * Constructor.
     */
    public function JaxwsTreeBranch(label:String, target:String) {
        super(label, "JAXWS", target);
    }

    protected override function mergeBranches(jaxwsIdentifier:String):void {

        // The expected format is the following (pseudo grammar)
        // identifier ::= qname '/' qname '/' qname
        // qname ::= '{' namespace '}' localpart
        //
        // Example:
        // {http://jonas.ow2.org/tutorial/jaxws/quote}QuoteReporterService/{http://jonas.ow2.org/tutorial/jaxws/quote}QuoteReporterPort/{http://jonas.ow2.org/tutorial/jaxws/quote}getQuote
        //
        // From this, we want to create the following tree:
        // QuoteReporterService
        //  \_QuoteReporterPort
        //     \_getQuote

        var parser:JaxwsIdentifierParser = new JaxwsIdentifierParser();
        parser.parse(jaxwsIdentifier);

        var serviceQName:QName = parser.serviceQName;
        var portQName:QName = parser.portQName;
        var operationQName:QName = parser.operationQName;

        var serviceNode:XML = <node label={serviceQName.localName}
                                    type={type}
                                    target={asString(serviceQName)} />;

        var portNode:XML = <node label={portQName.localName}
                                 type={type}
                                 target={serviceNode.@target + "/" + asString(portQName)} />;

        var operationNode:XML = <node label={operationQName.localName}
                                      type={type}
                                      target={portNode.@target + "/" + asString(operationQName)} />;

        var ops:XMLList = node..node.(@target == operationNode.@target);
        if (ops.length() == 0) {
            // The operation node is not in the tree
            portNode.appendChild(operationNode);

            var ports:XMLList = node..node.(@target == portNode.@target);
            if (ports.length() == 0) {
                // The port node is not in the tree
                serviceNode.appendChild(portNode);

                var services:XMLList = node..node.(@target == serviceNode.@target);
                if (services.length() == 0) {
                    // The service node is not in the tree
                    node.appendChild(serviceNode);

                } else {
                    // service node already exists
                    serviceNode = services[0];
                    serviceNode.appendChild(portNode);
                }

            } else {
                // port node already exists
                portNode = ports[0];
                portNode.appendChild(operationNode);
            }
        }

    }

    private function asString(name:QName):String {
        return "{" + name.uri + "}" + name.localName;
    }

}
}