/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JNDIAuditReportVO.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.vo {
import com.adobe.cairngorm.vo.IValueObject;

import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.auditconsole.util.IconsUtils;

/**
 * Object that represent a Jaxws audit report.
 */
[RemoteClass(alias="org.ow2.util.auditreport.impl.JaxwsAuditReport")]
[Bindable]
public class JaxwsAuditReportVO  extends GenericAuditReportVO implements IValueObject {

    public var serviceQName:String = "";
    public var portQName:String = "";
    public var operationQName:String = "";

    [ArrayElementType("String")]
    public var soapRoles:ArrayCollection = new ArrayCollection();

    public var startProcessingTimestamp:Number = 0;
    public var endProcessingTimestamp:Number = 0;

    /**
     * Constructor.
     */
    public function JaxwsAuditReportVO() {
        super();
    }

    public override function toString():String {
        return super.toString() +
        " Timestamp : " + requestTimeStamp +
        " Duration (ms) : " + duration +
        " Service QName : " + serviceQName +
        " Port QName : " + portQName +
		" Operation QName : " + operationQName +
        " SOAP Roles : " + soapRoles;
    }

    public override function toHTMLString():String {

        return super.toHTMLString() +
        "<font color=\"#FF0000\"><b>Request Timestamp</b></font> : " + requestTimeStamp + " ms <br/>" +
        "<font color=\"#FF0000\"><b>Duration (ms)</b></font> : " + duration + " ms <br/>" +
        "<font color=\"#FF0000\"><b>Service QName</b></font> : " + serviceQName + "<br/>" +
		"<font color=\"#FF0000\"><b>Port QName</b></font> : " + portQName + "<br/>" +
        "<font color=\"#FF0000\"><b>Operation QName</b></font> : " + operationQName + "<br/>" +
        "<font color=\"#FF0000\"><b>SOAP Roles</b></font> : " + soapRoles + "<br/>";
    }

    public override function isEJBInvocation():Boolean {
        return false;
    }

    public override function isWEBInvocation():Boolean {
        return false;
    }

    public override function isJNDIInvocation():Boolean {
        return false;
    }

    public override function isJaxwsInvocation():Boolean {
        return true;
    }

    public override function get type():String {
        return "Jaxws";
    }

    public override function get duration():Number {
        // Theses timestamps are expressed in nanoseconds and duration should be in milliseconds
        return (this.endProcessingTimestamp - startProcessingTimestamp) / 1000000;
    }

    /**
     * 'requestDuration' is an alias for duration property.
     */
    public function get requestDuration():Number {
        return duration;
    }

    public override function get gridTarget():String {
        return serviceQName + "/" + portQName + "/" + operationQName;
    }

    /**
     * 'paramSize' attribute is required for charts.
     */
    public function get paramSize():Number {
        return 0;
    }


}
}